@@ -26,5 +26,5 @@ def buildup(request):
     if request.method == 'GET':
         return render(request, f"bethany_ds/base.html", c)
     elif request.method == "POST":
-        c.update(make_post_context(request.POST, c['basic_info']['consult_email']))
+        c.update(make_post_context(request.POST, c['basic_info']['consult_email'], anchor='contact'))
         return render(request, f"bethany_ds/base.html", c)
